<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>@default</name>
    <message>
        <source>Initialization error</source>
        <translation type="obsolete">初始化错误</translation>
    </message>
    <message>
        <source>Could not find syntax definitions. Check installation.</source>
        <translation type="obsolete">找不到语法定义文件.请检查安装.</translation>
    </message>
    <message>
        <source>Select one or more files to open</source>
        <translation type="obsolete">选择一个或多个文件打开</translation>
    </message>
    <message>
        <source>Select destination directory</source>
        <translation type="obsolete">选择目标路径</translation>
    </message>
    <message>
        <source>Tags file error</source>
        <translation type="obsolete">Tags文件错误</translation>
    </message>
    <message>
        <source>Could not read tags information in &quot;%1&quot;</source>
        <translation type="obsolete">无法读取 &quot;%1&quot; 的Tag信息</translation>
    </message>
    <message>
        <source>Output error</source>
        <translation type="obsolete">输出错误</translation>
    </message>
    <message>
        <source>Output directory does not exist!</source>
        <translation type="obsolete">输出目录错误！</translation>
    </message>
    <message>
        <source>You must define a style output file!</source>
        <translation type="obsolete">你必须等译一个style输出文件！</translation>
    </message>
    <message>
        <source>Language definition error</source>
        <translation type="obsolete">语言定义错误</translation>
    </message>
    <message>
        <source>Invalid regular expression in %1:
%2</source>
        <translation type="obsolete">错误的正则表达式 %1:
%2</translation>
    </message>
    <message>
        <source>Unknown syntax</source>
        <translation type="obsolete">未知的语法定义</translation>
    </message>
    <message>
        <source>Could not convert %1</source>
        <translation type="obsolete">%1转换失败</translation>
    </message>
    <message>
        <source>Converted %1 files in %2 ms</source>
        <translation type="obsolete">文件%1 转换完毕，用时 %2 ms</translation>
    </message>
    <message>
        <source>Conversion of &quot;%1&quot; not possible.</source>
        <translation type="obsolete">%1 转换不可用.</translation>
    </message>
    <message>
        <source>clipboard data</source>
        <translation type="obsolete">剪贴板数据</translation>
    </message>
    <message>
        <source>%1 options</source>
        <translation type="obsolete">%1 选项</translation>
    </message>
    <message>
        <source>Preview (%1):</source>
        <translation type="obsolete">预览 (%1):</translation>
    </message>
    <message>
        <source>Current syntax: %1</source>
        <translation type="obsolete">当前语言: %1</translation>
    </message>
    <message>
        <source>Preview of &quot;%1&quot; not possible.</source>
        <translation type="obsolete">&quot;%1&quot;.的预览不可用.</translation>
    </message>
    <message>
        <source>Choose a ctags file</source>
        <translation type="obsolete">选择一个ctags文件</translation>
    </message>
    <message>
        <source>Choose a style include file</source>
        <translation type="obsolete">选择一个style文件</translation>
    </message>
    <message>
        <source>About providing translations</source>
        <translation type="obsolete">关于提供翻译文件</translation>
    </message>
    <message>
        <source>The GUI was developed using the Qt toolkit, and translations may be provided using the tools Qt Linguist and lrelease.
The highlight.ts file for Linguist resides in the src/gui-qt subdirectory.
The qm file generated by lrelease has to be saved in gui-files/l10n.

Please send a note to as (at) andre-simon (dot) de if you have issues during translating or if you have finished or updated a translation.</source>
        <translation type="obsolete">这个GUI界面程序使用Qt开发，翻译可以通过Qt开发工具中的Qt Linguist和lrelease.
用于翻译的highlight.ts文件保存在src/gui-qt子目录中.
通过lrelease生成的qm文件需要保存在gui-files/l10n目录下.
如果你在翻译过程中遇到了问题，或者你弯沉或者更新了翻译
请通过as (at) andre-simon (dot) de联系我.</translation>
    </message>
    <message>
        <source>Select one or more plug-ins</source>
        <translation type="obsolete">选择一个或多个插件</translation>
    </message>
    <message>
        <source>Choose a plug-in input file</source>
        <translation type="obsolete">选择插件输入目录</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Themes or indent schemes not found.
Check installation.</source>
        <translation type="obsolete">Temas o esquemas de indentación no encontrados
Revise su instalación.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="+105"/>
        <source>Initialization error</source>
        <translation type="unfinished">初始化错误</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Could not find syntax definitions. Check installation.</source>
        <translation type="unfinished">找不到语法定义文件.请检查安装.</translation>
    </message>
    <message>
        <location line="+76"/>
        <source>Always at your service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Select one or more files to open</source>
        <translation type="unfinished">选择一个或多个文件打开</translation>
    </message>
    <message>
        <location line="+37"/>
        <source>Select destination directory</source>
        <translation type="unfinished">选择目标路径</translation>
    </message>
    <message>
        <source>Tags file error</source>
        <translation type="obsolete">Tags文件错误</translation>
    </message>
    <message>
        <source>Could not read tags information in &quot;%1&quot;</source>
        <translation type="obsolete">无法读取 &quot;%1&quot; 的Tag信息</translation>
    </message>
    <message>
        <location line="+632"/>
        <location line="+31"/>
        <source>Output error</source>
        <translation type="unfinished">输出错误</translation>
    </message>
    <message>
        <location line="-31"/>
        <source>Output directory does not exist!</source>
        <translation type="unfinished">输出目录错误！</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>You must define a style output file!</source>
        <translation type="unfinished">你必须等译一个style输出文件！</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Processing %1 (%2/%3)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Language definition error</source>
        <translation type="unfinished">语言定义错误</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Invalid regular expression in %1:
%2</source>
        <translation type="unfinished">错误的正则表达式 %1:
%2</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Unknown syntax</source>
        <translation type="unfinished">未知的语法定义</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Could not convert %1</source>
        <translation type="unfinished">%1转换失败</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Lua error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Could not convert %1:
Lua Syntax error: %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+73"/>
        <source>Converted %1 files in %2 ms</source>
        <translation type="unfinished">文件%1 转换完毕，用时 %2 ms</translation>
    </message>
    <message>
        <location line="+98"/>
        <source>Conversion of &quot;%1&quot; not possible.</source>
        <translation type="unfinished">No es posible la conversión de &quot;%1&quot;.</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+118"/>
        <location line="+25"/>
        <source>clipboard data</source>
        <translation type="unfinished">剪贴板数据</translation>
    </message>
    <message>
        <location line="-76"/>
        <source>%1 options</source>
        <translation type="unfinished">%1 选项</translation>
    </message>
    <message>
        <location line="+37"/>
        <location line="+6"/>
        <source>(user script)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Preview (%1):</source>
        <translation type="unfinished">预览 (%1):</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Current syntax: %1 %2</source>
        <translation type="unfinished">当前语言: %1 %2</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Current theme: %1 %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current syntax: %1</source>
        <translation type="obsolete">当前语言: %1</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Preview of &quot;%1&quot; not possible.</source>
        <translation type="unfinished">&quot;%1&quot;.的预览不可用.</translation>
    </message>
    <message>
        <location line="+251"/>
        <source>Some plug-in effects may not be visible in the preview.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose a ctags file</source>
        <translation type="obsolete">选择一个ctags文件</translation>
    </message>
    <message>
        <location line="-214"/>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+5"/>
        <source>Choose a style include file</source>
        <translation type="unfinished">选择一个style文件</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>About providing translations</source>
        <translation type="unfinished">关于提供翻译文件</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The GUI was developed using the Qt toolkit, and translations may be provided using the tools Qt Linguist and lrelease.
The highlight.ts file for Linguist resides in the src/gui-qt subdirectory.
The qm file generated by lrelease has to be saved in gui-files/l10n.

Please send a note to as (at) andre-simon (dot) de if you have issues during translating or if you have finished or updated a translation.</source>
        <translation type="unfinished">这个GUI界面程序使用Qt开发，翻译可以通过Qt开发工具中的Qt Linguist和lrelease.
用于翻译的highlight.ts文件保存在src/gui-qt子目录中.
通过lrelease生成的qm文件需要保存在gui-files/l10n目录下.
如果你在翻译过程中遇到了问题，或者你弯沉或者更新了翻译
请通过as (at) andre-simon (dot) de联系我.</translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Select one or more plug-ins</source>
        <translation type="unfinished">选择一个或多个插件</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Select one or more syntax or theme scripts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+60"/>
        <source>Choose a plug-in input file</source>
        <translation type="unfinished">选择插件输入目录</translation>
    </message>
</context>
<context>
    <name>MainWindowClass</name>
    <message>
        <location filename="mainwindow.ui" line="+180"/>
        <source>Choose the source code files you want to convert.</source>
        <translation>选择你想要转换的代码文件.</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Choose input files</source>
        <translation>选择输入文件</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>List of input files.</source>
        <translation>输入文件列表.</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Remove the selected input files.</source>
        <translation>移除选中的输入文件.</translation>
    </message>
    <message>
        <location line="+3"/>
        <location line="+314"/>
        <location line="+136"/>
        <source>Clear selection</source>
        <translation>移除选中项</translation>
    </message>
    <message>
        <location line="-443"/>
        <source>Remove all input files.</source>
        <translation>清除所有输入文件.</translation>
    </message>
    <message>
        <location line="+3"/>
        <location line="+314"/>
        <location line="+136"/>
        <source>Clear all</source>
        <translation>移除所有</translation>
    </message>
    <message>
        <source>Output destination</source>
        <translation type="obsolete">Destino de salida</translation>
    </message>
    <message>
        <location line="-411"/>
        <source>Output directory</source>
        <translation>输出目录</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Select the output directory.</source>
        <translation>选择输出路径.</translation>
    </message>
    <message>
        <location line="+3"/>
        <location line="+330"/>
        <location line="+646"/>
        <location line="+269"/>
        <location line="+108"/>
        <location line="+295"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location line="-1613"/>
        <source>Save output in the input file directories.</source>
        <translation>将输出保存在输入路径中.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Write to source directories</source>
        <translation>输出到源文件目录</translation>
    </message>
    <message>
        <source>Output options</source>
        <translation type="obsolete">Opciones de salida</translation>
    </message>
    <message>
        <location line="+408"/>
        <source>General</source>
        <translation>通用</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Output for&amp;mat:</source>
        <oldsource>Output format:</oldsource>
        <translation type="unfinished">输出格式：</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Choose an output format.</source>
        <translation>选择一个输出格式.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>HTML</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>XHTML</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>LaTeX</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>TeX</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>RTF</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>ODT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>SVG</source>
        <translation></translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Add line numbers to the output.</source>
        <translation>给输出添加代码行号.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Add line numbers</source>
        <translation>添加行号</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Select the line number width.</source>
        <translation>选择行号宽度.</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Fill leading space of line numbers with zeroes.</source>
        <translation>行号用0补齐.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Pad with zeroes</source>
        <translation>行号用0补齐</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Generate output without document header and footer.</source>
        <translation>去掉输出文件的头部和尾部声明部分,便于将其插入其他文档中.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Omit header and footer</source>
        <translation>去掉文档的头部和尾部声明</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Output any plug-in text injections even if document header and footer is omitted.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Keep Plug-In injections</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Test if input data is not binary.
Removes Unicode BOM mark.</source>
        <translation>检测输入文件是否是二进制.
清除Unicode的BOM标记.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Validate input data</source>
        <translation>验证输入文件</translation>
    </message>
    <message>
        <source>Set the output file ancoding.</source>
        <translation type="vanished">设置输出文件的编码格式.</translation>
    </message>
    <message>
        <location line="+1472"/>
        <source>&amp;Plug-Ins</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Encoding:</source>
        <translation type="obsolete">Codificación:</translation>
    </message>
    <message>
        <location line="-1443"/>
        <source>Select or define the encoding.
The result has to match the input file encoding.</source>
        <translation>选择或者定义编码格式.
结果必须和输出文件的编码格式相符合.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>ISO-8859-1</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>ISO-8859-2</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>ISO-8859-3</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>ISO-8859-4</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>ISO-8859-5</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>ISO-8859-6</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>ISO-8859-7</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>ISO-8859-8</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>ISO-8859-9</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>ISO-8859-10</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>ISO-8859-11</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>ISO-8859-12</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>ISO-8859-13</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>ISO-8859-14</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>ISO-8859-15</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>UTF-8</source>
        <translation></translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Output specific</source>
        <translation>输出细节</translation>
    </message>
    <message>
        <source>HTML options</source>
        <translation type="obsolete">Opciones de HTML</translation>
    </message>
    <message>
        <source>Style</source>
        <translation type="obsolete">Hoja de estilo</translation>
    </message>
    <message>
        <location line="+49"/>
        <location line="+326"/>
        <location line="+108"/>
        <location line="+295"/>
        <source>Include the style information in each output file.</source>
        <translation>将样式表信息保存到每个输出文件中.</translation>
    </message>
    <message>
        <location line="-726"/>
        <location line="+729"/>
        <source>Embed style (CSS)</source>
        <translation>内嵌样式表 (CSS)</translation>
    </message>
    <message>
        <location line="-716"/>
        <source>Add CSS information to each tag (do not use CSS class definitions).</source>
        <translation>CSS信息保存到每个Tag中(不使用CSS的类定义).</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Inline CSS</source>
        <translation>Inline CSS</translation>
    </message>
    <message>
        <source>Style file:</source>
        <translation type="obsolete">Archivo de estilo:</translation>
    </message>
    <message>
        <location line="+60"/>
        <location line="+383"/>
        <location line="+295"/>
        <source>Name of the referenced style file.</source>
        <translation>外链样式表文件的名字.</translation>
    </message>
    <message>
        <location line="-675"/>
        <location line="+678"/>
        <source>highlight.css</source>
        <translation></translation>
    </message>
    <message>
        <source>Style include file:</source>
        <translation type="obsolete">Archivo de estilo a incluir:</translation>
    </message>
    <message>
        <location line="-637"/>
        <location line="+672"/>
        <source>Path of the CSS include file.</source>
        <translation>外链样式表的路径.</translation>
    </message>
    <message>
        <location line="-659"/>
        <source>Select a CSS include file.</source>
        <translation>选择一个外链的样式表.</translation>
    </message>
    <message>
        <location line="-103"/>
        <source>CSS class prefix:</source>
        <translation>CSS类前缀:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Add a CSS class name prefix to avoid namespace clashes.</source>
        <translation>给CSS类添加前缀以避免由于命名空间引起的冲突..</translation>
    </message>
    <message>
        <source>Tags and index files</source>
        <translation type="obsolete">Archivos de etiquetas e índice</translation>
    </message>
    <message>
        <location line="+175"/>
        <source>Generate an index file with hyperlinks to all outputted files.</source>
        <translation>生成一个包含所有输出文件超链接的index文件.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Generate index file</source>
        <translation>生成index文件</translation>
    </message>
    <message>
        <source>Read a ctags file and add the included metainformation as tooltips.
See ctags.sf.net for details.</source>
        <translatorcomment>This text will be emoved soon</translatorcomment>
        <translation type="obsolete">根据读取的一个ctags文件添加提示.
更多详情请访问 ctags.sf.net.</translation>
    </message>
    <message>
        <source>Ctags file:</source>
        <translation type="obsolete">Archivo de ctags:</translation>
    </message>
    <message>
        <source>Path of the ctags file.</source>
        <translation type="obsolete">ctags文件路径..</translation>
    </message>
    <message>
        <source>Choose a ctags file.</source>
        <translation type="obsolete">选择一个ctags文件.</translation>
    </message>
    <message>
        <location line="-59"/>
        <source>Misc</source>
        <translation>杂项</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Add an achor to each line.</source>
        <translation>给每一行代码添加锚点..</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Add line anchors</source>
        <translation>给每一行代码添加Anchor(锚点)</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Add the filename as prefix to the anchors.</source>
        <translation>将文件名作为Anchors(锚点)的前缀.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Include file name in anchor</source>
        <translation>将文件名包含在Anchor(锚点)中</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Output the lines within an ordered list.</source>
        <translation>根据列表顺序输出文档..</translation>
    </message>
    <message>
        <source>Ordered list</source>
        <translation type="obsolete">Lista ordenada</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Add &amp;lt;pre&amp;gt; tags to the output, if the flag &quot;No document header and footer&quot; is selected.</source>
        <translation>当选中“忽略文档的header和footer”时，给输出添加&lt;pre&gt;标签.</translation>
    </message>
    <message>
        <source>Enclose in &lt;pre&gt;</source>
        <translation type="obsolete">Meter entre &amp;lt;pre&amp;gt;</translation>
    </message>
    <message>
        <source>LaTeX options</source>
        <translation type="obsolete">Opciones de LaTeX</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Replace quotes by dq sequences.</source>
        <translatorcomment>Replace apostrophes by dq strings</translatorcomment>
        <translation>用dq序列替换引号.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Escape quotes</source>
        <translatorcomment>Replace apostrophes</translatorcomment>
        <translation>替换引号</translation>
    </message>
    <message>
        <source>Make output Babel compatible.</source>
        <translatorcomment>Make output work with Babel package</translatorcomment>
        <translation type="vanished">使输出与Babel宏包兼容.</translation>
    </message>
    <message>
        <source>Babel compatibility</source>
        <translation type="obsolete">Compatibilidad con Babel</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Replace default symbols (brackets, tilde) by nice redefinitions.</source>
        <translatorcomment>User more pleasant symbols</translatorcomment>
        <translation>用更友好的定义替换默认符号 (如：括号, 波浪符号).</translation>
    </message>
    <message>
        <source>Pretty symbols</source>
        <translation type="obsolete">Símbolos lindos</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Embed style (defs)</source>
        <translatorcomment>Include style information in output</translatorcomment>
        <translation>内嵌页面样式 (defs)</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Name of the referenced  style file.</source>
        <translatorcomment>Name of external style file</translatorcomment>
        <translation>被引用的样式表的文件名.</translation>
    </message>
    <message>
        <location line="+3"/>
        <location line="+108"/>
        <source>highlight.sty</source>
        <translation></translation>
    </message>
    <message>
        <source>Style include:</source>
        <translation type="obsolete">Incluir estilo:</translation>
    </message>
    <message>
        <location line="-631"/>
        <source>Set encoding:</source>
        <translation>编码设置：</translation>
    </message>
    <message>
        <location line="-708"/>
        <source>Output destination:</source>
        <translation>输出路径：</translation>
    </message>
    <message>
        <location line="+934"/>
        <location line="+278"/>
        <location line="+108"/>
        <location line="+295"/>
        <source>Stylesheet file:</source>
        <translation>外链样式表文件名：</translation>
    </message>
    <message>
        <location line="-648"/>
        <location line="+275"/>
        <location line="+108"/>
        <location line="+295"/>
        <source>Stylesheet include file:</source>
        <translation>包含的样式表文件：</translation>
    </message>
    <message>
        <source>Read ctags file:</source>
        <translation type="obsolete">读取ctags文件：</translation>
    </message>
    <message>
        <location line="-1901"/>
        <source>Highlight</source>
        <translation>Highlight</translation>
    </message>
    <message>
        <location line="+157"/>
        <source>Files</source>
        <translation>文件</translation>
    </message>
    <message>
        <location line="+261"/>
        <source>Paste clipboard content into the preview window.</source>
        <translation>将剪贴板中的代码粘贴到预览窗口.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Paste from clipboard (%1)</source>
        <oldsource>Paste from clipboard</oldsource>
        <translation type="unfinished">从剪贴板获取代码</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Copy highlighted code into the clipboard.</source>
        <translation>将高亮代码复制到剪贴板.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Copy preview to clipboard (%1)</source>
        <oldsource>Copy preview to clipboard</oldsource>
        <translation type="unfinished">将预览结果复制到剪贴板</translation>
    </message>
    <message>
        <location line="-39"/>
        <source>Select syntax:</source>
        <translation>代码语言：</translation>
    </message>
    <message>
        <location line="-310"/>
        <source>Wi&amp;ndows</source>
        <oldsource>&amp;Windows</oldsource>
        <translation type="unfinished">窗口(&amp;W)</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>H&amp;ighlighting options</source>
        <oldsource>Highlighting options</oldsource>
        <translation type="unfinished">代码高亮选项</translation>
    </message>
    <message>
        <location line="+297"/>
        <source>Select the correct syntax of the code snippet.</source>
        <translation>给代码片段选择对应的语言格式.</translation>
    </message>
    <message>
        <location line="+86"/>
        <source>Plug-ins</source>
        <translation>插件</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Add plug-in to pool</source>
        <translation>添加插件</translation>
    </message>
    <message>
        <location line="+51"/>
        <location line="+136"/>
        <source>Description</source>
        <translation>描述</translation>
    </message>
    <message>
        <location line="-124"/>
        <source>Shows decription of a selected plug-in script.</source>
        <translation>显示选中插件的描述.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Plug-In description</source>
        <translation>插件描述</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Plug-in parameter</source>
        <oldsource>Plug-in input file</oldsource>
        <translation type="unfinished">输入插件的文件</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Optional plug-in parameter, this may be a path to a plug-in input file</source>
        <oldsource>Optional path to a plug-in input file</oldsource>
        <translation type="unfinished">传递给插件的一个可选路径</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Select the plug-in input file.</source>
        <translation>选择传递给插件的文件.</translation>
    </message>
    <message>
        <location line="+200"/>
        <source>BBCode</source>
        <translation>BBCode</translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Set line numbering start.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+260"/>
        <source>Stylesheets</source>
        <translation>样式表</translation>
    </message>
    <message>
        <source>Include:</source>
        <translation type="vanished">包含：</translation>
    </message>
    <message>
        <source>Index/ctags</source>
        <translation type="obsolete">Index/ctags</translation>
    </message>
    <message>
        <location line="+185"/>
        <source>Line numbering options:</source>
        <translation>行号选项：</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Output as ordered list</source>
        <translation>根据列表顺序输出</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Enclose in pre tags</source>
        <translation>包含在pre标记中</translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Add Babel compatibility</source>
        <translation>兼容Babel宏包</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Add pretty symbols</source>
        <translatorcomment>User nicer symbols</translatorcomment>
        <translation>使用更友好的符号</translation>
    </message>
    <message>
        <location line="+80"/>
        <location line="+108"/>
        <source>Path of the style include file.</source>
        <translatorcomment>Ptah of file to be included in document style</translatorcomment>
        <translation>外链样式表的路径.</translation>
    </message>
    <message>
        <location line="-95"/>
        <location line="+108"/>
        <location line="+295"/>
        <source>Select a style include file.</source>
        <translation>选择一个样式表文件.</translation>
    </message>
    <message>
        <source>TeX options</source>
        <translation type="obsolete">Opciones de TeX</translation>
    </message>
    <message>
        <location line="-371"/>
        <source>Embed style (macros)</source>
        <translation>内嵌页面样式 (macros)</translation>
    </message>
    <message>
        <source>RTF options</source>
        <translation type="obsolete">Opciones de RTF</translation>
    </message>
    <message>
        <location line="+105"/>
        <source>Add character stylesheets with formatting information.
You can select the stylesheets in your word processor to reformat additional text.</source>
        <translatorcomment>For RTF output, Openoffice supports character stylesheets</translatorcomment>
        <translation>将高亮风格的格式信息添加到字体样式中.
你可以在你的文字处理软件中通过选择对应的样式来格式化附加的文字.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Add character styles</source>
        <translation>添加字体样式</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Set page color attribute to background color.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Page size:</source>
        <translation>页面大小：</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Select a page size.</source>
        <translation>设置页面大小.</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>A3</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>A4</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>A5</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>B4</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>B5</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>B6</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Letter</source>
        <translation>Letter</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Legal</source>
        <translation>正规</translation>
    </message>
    <message>
        <source>SVG options</source>
        <translation type="obsolete">Opciones de SVG</translation>
    </message>
    <message>
        <source>Image size:</source>
        <translation type="vanished">图像大小：</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation type="vanished">宽度：</translation>
    </message>
    <message>
        <location line="+57"/>
        <source>Enter the SVG width (may contain units).</source>
        <translatorcomment>Input SVG image width</translatorcomment>
        <translation>输入SVG图像宽度.</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Height:</source>
        <translation>高度：</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Enter the SVG height (may contain units).</source>
        <translatorcomment>Input SVG image height</translatorcomment>
        <translation>输入SVG图像高度.</translation>
    </message>
    <message>
        <location line="+124"/>
        <source>No options defined.</source>
        <translation>没有可供选择的选项..</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Formatting</source>
        <translation>格式化</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Color theme:</source>
        <translation>高亮主题：</translation>
    </message>
    <message>
        <location line="+54"/>
        <source>Select a colour theme.</source>
        <translation>选择一个用于高亮的颜色主题.</translation>
    </message>
    <message>
        <source>Reformat and indent your code.
This feature is enabled tor C, C++, C# and Java code.</source>
        <translation type="vanished">重新格式化排版你的代码.
这项功能仅支持 C, C++, C# 和 Java.</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Reformat:</source>
        <translation>格式化代码:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Choose a formatting scheme.</source>
        <translation>选择一种代码格式化风格.</translation>
    </message>
    <message>
        <source>Linux</source>
        <translation type="obsolete">Linux</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Change the keyword case.</source>
        <translation>改变关键字大小写.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Keyword case:</source>
        <translation>关键字大小写：</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Select a keyword case.</source>
        <translation>这是关键字大小写.</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>UPPER</source>
        <translation>大写</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>lower</source>
        <translation>小写</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Capitalize</source>
        <translation>首字母大写</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Tab width:</source>
        <translation>制表符(Tab)宽度：</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Enter the number of spaces which replace a tab.
Set the width to 0 to keep tabs.</source>
        <translation>设置多少个空格替换一个制表符(Tab).
设置为0时保留制表符(Tab).</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Enable line wrapping.</source>
        <translation>启用自动换行.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Line wrapping</source>
        <translation>自动换行</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Enter the maximum line length.</source>
        <translation>设定每行代码的最大长度.</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Indent statements and function parameters after wrapping.</source>
        <translation>换行后自动缩进语句和函数参数.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intelligent wrapping</source>
        <translation>自动缩进</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Font na&amp;me:</source>
        <oldsource>Font name:</oldsource>
        <translation type="unfinished">字体：</translation>
    </message>
    <message>
        <source>Select or enter the font name.</source>
        <translation type="obsolete">Seleccionar o introduzcir el nombre de la fuente.</translation>
    </message>
    <message>
        <source>Font size:</source>
        <translation type="vanished">字体大小：</translation>
    </message>
    <message>
        <location line="+55"/>
        <source>Enter the font size.</source>
        <translation>输入字体大小.</translation>
    </message>
    <message>
        <location line="+73"/>
        <source>&amp;Visit andre-simon.de</source>
        <oldsource>Visit andre-simon.de</oldsource>
        <translation type="unfinished">访问 andre-simon.de</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Dock floating panels</source>
        <translation>停靠浮动面板(&amp;D)</translation>
    </message>
    <message>
        <location line="-2396"/>
        <source>Preview</source>
        <translation>预览</translation>
    </message>
    <message>
        <location line="+353"/>
        <source>Start the conversion of your input files.</source>
        <translation>点击按钮开始转换文件.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Convert files</source>
        <translation>转换文件</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Copy highlighted code of the seleted file into the clipboard.</source>
        <translation>将选中文件的高亮代码复制到剪贴板中.</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Clipboard</source>
        <translation>剪贴板</translation>
    </message>
    <message>
        <location line="-12"/>
        <source>Copy file to clipboard</source>
        <translation>将输出文件内容复制到剪贴板</translation>
    </message>
    <message>
        <location line="+119"/>
        <source>Choose a plug-in script.</source>
        <translation>选择一个插件脚本.</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>List of plug-ins. Toggle checkbox to enable the scripts. The preview window may not display all plug-in effects.</source>
        <oldsource>List of plug-ins. Toggle checkbox to enable the scripts.</oldsource>
        <translation type="unfinished">插件列表. 打钩激活对应脚本.</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Remove the selected plug-ins.</source>
        <translation>移除所有选中的插件.</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Remove all plug-ins.</source>
        <translation>移除所有插件.</translation>
    </message>
    <message>
        <location line="-502"/>
        <source>Output progress:</source>
        <translation>输出进度：</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>&amp;File</source>
        <translation>文件(&amp;F)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Help</source>
        <translation>帮助(&amp;H)</translation>
    </message>
    <message>
        <location line="+235"/>
        <source>Browse output directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+152"/>
        <source>Paste code from clipboard and copy the output back in one step</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Paste, Convert and Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+167"/>
        <source>Scripts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Choose a custom syntax or theme script.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Add custom script to pool</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+14"/>
        <source>You can check one file of each type (syntax and theme) to override the default behaviour. If checked, the scripts will be watched for changes.</source>
        <oldsource>You can check one file of each type (syntax and theme) to override the default behaviour.</oldsource>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Remove the selected scripts.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Remove all scripts.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Shows decription of a selected script.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Script description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+249"/>
        <source>Generate output without version information comment.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Omit version info comment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Set the output file encoding.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+417"/>
        <source>Add HTML MIME Type when copying code to the clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Copy with MIME type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+38"/>
        <source>Adapt output for the Babel package</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Adapt output for the Beamer package</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Add Beamer compatibility</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+254"/>
        <source>Set page color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+93"/>
        <source>I&amp;mage width:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+268"/>
        <source>Toggle classic theme or Base16 theme selection.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Base16</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Reformat and indent your code.
This feature is enabled for C, C++, C# and Java code.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+170"/>
        <source>Do not add line numbering to lines which were automatically wrapped.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Omit line numbers of wrapped lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Select or enter the font name. HTML supports a list of fonts, separated with comma.</source>
        <translation>选择或者输入字体名. HTML支持用逗号分隔的字体列表.</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Font si&amp;ze:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+37"/>
        <source>&amp;Open files</source>
        <translation>打开(&amp;O)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Exit</source>
        <translation>退出(&amp;E)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Load</source>
        <translation>加载(&amp;L)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Save</source>
        <translation>保存(&amp;S)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Load &amp;default project</source>
        <translation>加载默认工程(&amp;D)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Readme</source>
        <oldsource>Readme</oldsource>
        <translation type="unfinished">ReadMe</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Tips</source>
        <translation>小贴士(&amp;T)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Changelog</source>
        <translation>查看变更(&amp;C)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;License</source>
        <translation>许可证(&amp;L)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;About Highlight</source>
        <translation>关于Highlight(&amp;A)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>A&amp;bout translations</source>
        <oldsource>About &amp;translations</oldsource>
        <translation type="unfinished">关于翻译(&amp;T)</translation>
    </message>
</context>
<context>
    <name>ShowTextFile</name>
    <message>
        <location filename="showtextfile.ui" line="+17"/>
        <source>Show text</source>
        <translation>文本显示</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>TextLabel</source>
        <translation></translation>
    </message>
    <message>
        <location line="+32"/>
        <source>OK</source>
        <translation>确定</translation>
    </message>
</context>
<context>
    <name>io_report</name>
    <message>
        <location filename="io_report.ui" line="+14"/>
        <source>Error summary</source>
        <translatorcomment>错误总结</translatorcomment>
        <translation>Resumen de Error</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Input errors:</source>
        <translation>输入错误:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Remove files above from input file list</source>
        <translation>将以上文件从输入文件列表中移除</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Output errors:</source>
        <translation>输出错误:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Reformatting not possible:</source>
        <translation>不支持代码格式化的文件:</translation>
    </message>
</context>
<context>
    <name>syntax_chooser</name>
    <message>
        <location filename="syntax_chooser.ui" line="+14"/>
        <source>Syntax selection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Select correct syntax</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+18"/>
        <source>TextLabel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+24"/>
        <source>These entries are configured in filetypes.conf.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>The selection will be remembered for this session.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Remember selection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="syntax_chooser.cpp" line="+57"/>
        <source>The file extension %1 is assigned to multiple syntax definitions.
Select the correct one:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
